==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/msk/kotlin/inputs/ClusterClientAuthenticationSaslArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.msk.kotlin.inputs

import com.pulumi.aws.msk.inputs.ClusterClientAuthenticationSaslArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Boolean
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property iam Enables IAM client authentication. Defaults to `false`.
 * @property scram Enables SCRAM client authentication via AWS Secrets Manager. Defaults to `false`.
 */
public data class ClusterClientAuthenticationSaslArgs(
    public val iam: Output<Boolean>? = null,
    public val scram: Output<Boolean>? = null,
) : ConvertibleToJava<com.pulumi.aws.msk.inputs.ClusterClientAuthenticationSaslArgs> {
    override fun toJava(): com.pulumi.aws.msk.inputs.ClusterClientAuthenticationSaslArgs =
        com.pulumi.aws.msk.inputs.ClusterClientAuthenticationSaslArgs.builder()
            .iam(iam?.applyValue({ args0 -> args0 }))
            .scram(scram?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ClusterClientAuthenticationSaslArgs].
 */
@PulumiTagMarker
public class ClusterClientAuthenticationSaslArgsBuilder internal constructor() {
    private var iam: Output<Boolean>? = null

    private var scram: Output<Boolean>? = null

    /**
     * @param value Enables IAM client authentication. Defaults to `false`.
     */
    @JvmName("txdjscwimxsbidxr")
    public suspend fun iam(`value`: Output<Boolean>) {
        this.iam = value
    }

    /**
     * @param value Enables SCRAM client authentication via AWS Secrets Manager. Defaults to `false`.
     */
    @JvmName("esqadorwyoswxeof")
    public suspend fun scram(`value`: Output<Boolean>) {
        this.scram = value
    }

    /**
     * @param value Enables IAM client authentication. Defaults to `false`.
     */
    @JvmName("kfyukmrfftwhjcso")
    public suspend fun iam(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.iam = mapped
    }

    /**
     * @param value Enables SCRAM client authentication via AWS Secrets Manager. Defaults to `false`.
     */
    @JvmName("hjmenpbtjvksftva")
    public suspend fun scram(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.scram = mapped
    }

    internal fun build(): ClusterClientAuthenticationSaslArgs = ClusterClientAuthenticationSaslArgs(
        iam = iam,
        scram = scram,
    )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/msk/kotlin/inputs/ClusterClientAuthenticationSaslArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.msk.kotlin.inputs

import com.pulumi.aws.msk.inputs.ClusterClientAuthenticationSaslArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Boolean
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property iam
 * @property scram
 */
public data class ClusterClientAuthenticationSaslArgs(
    public val iam: Output<Boolean>? = null,
    public val scram: Output<Boolean>? = null,
) : ConvertibleToJava<com.pulumi.aws.msk.inputs.ClusterClientAuthenticationSaslArgs> {
    override fun toJava(): com.pulumi.aws.msk.inputs.ClusterClientAuthenticationSaslArgs =
        com.pulumi.aws.msk.inputs.ClusterClientAuthenticationSaslArgs.builder()
            .iam(iam?.applyValue({ args0 -> args0 }))
            .scram(scram?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ClusterClientAuthenticationSaslArgs].
 */
@PulumiTagMarker
public class ClusterClientAuthenticationSaslArgsBuilder internal constructor() {
    private var iam: Output<Boolean>? = null

    private var scram: Output<Boolean>? = null

    /**
     * @param value
     */
    @JvmName("bwrlwjtrtmucsiiu")
    public suspend fun iam(`value`: Output<Boolean>) {
        this.iam = value
    }

    /**
     * @param value
     */
    @JvmName("rdjljptmpyxmfclb")
    public suspend fun scram(`value`: Output<Boolean>) {
        this.scram = value
    }

    /**
     * @param value
     */
    @JvmName("jnouphnvqobbfhjw")
    public suspend fun iam(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.iam = mapped
    }

    /**
     * @param value
     */
    @JvmName("awkgcbrhxgefkhph")
    public suspend fun scram(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.scram = mapped
    }

    internal fun build(): ClusterClientAuthenticationSaslArgs = ClusterClientAuthenticationSaslArgs(
        iam = iam,
        scram = scram,
    )
}
